aboutsummaryrefslogtreecommitdiffstats
path: root/include/call.h
diff options
context:
space:
mode:
authorJoerie de Gram <j.de.gram@gmail.com>2011-08-17 15:57:47 +0200
committerJoerie de Gram <j.de.gram@gmail.com>2011-08-17 15:57:47 +0200
commitd3bd80a932e4f76b6cae280c78f118882f3b176d (patch)
treecad99877da53cad9fae5907fd43fe5a79e50ad37 /include/call.h
parenta3c46bd32430db57b97a1498d3da9a2c01df22ad (diff)
downloadexternal_libsamsung-ipc-d3bd80a932e4f76b6cae280c78f118882f3b176d.zip
external_libsamsung-ipc-d3bd80a932e4f76b6cae280c78f118882f3b176d.tar.gz
external_libsamsung-ipc-d3bd80a932e4f76b6cae280c78f118882f3b176d.tar.bz2
Rename library to libsamsung-ipc
Diffstat (limited to 'include/call.h')
-rw-r--r--include/call.h74
1 files changed, 37 insertions, 37 deletions
diff --git a/include/call.h b/include/call.h
index 3f04068..996f563 100644
--- a/include/call.h
+++ b/include/call.h
@@ -1,20 +1,20 @@
/**
* This file is part of libmsm-h1.
*
* Copyright (C) 2010-2011 Joerie de Gram <j.de.gram@gmail.com>
*
* libmsm-h1 is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* libmsm-h1 is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with libmsm-h1. If not, see <http://www.gnu.org/licenses/>.
+ * along with libsamsung-ipc. If not, see <http://www.gnu.org/licenses/>.
*
*/
@@ -22,64 +22,64 @@
#define __CALL_H__
/* Message types */
-#define MSM_CALL_OUTGOING 0x0201
-#define MSM_CALL_INCOMING 0x0202
-#define MSM_CALL_RELEASE 0x0203
-#define MSM_CALL_ANSWER 0x0204
-#define MSM_CALL_STATUS 0x0205
-#define MSM_CALL_LIST 0x0206
-#define MSM_CALL_BURST_DTMF 0x0207
-#define MSM_CALL_CONT_DTMF 0x0208
-#define MSM_CALL_WAITING 0x0209
-#define MSM_CALL_LINE_ID 0x020A
+#define IPC_CALL_OUTGOING 0x0201
+#define IPC_CALL_INCOMING 0x0202
+#define IPC_CALL_RELEASE 0x0203
+#define IPC_CALL_ANSWER 0x0204
+#define IPC_CALL_STATUS 0x0205
+#define IPC_CALL_LIST 0x0206
+#define IPC_CALL_BURST_DTMF 0x0207
+#define IPC_CALL_CONT_DTMF 0x0208
+#define IPC_CALL_WAITING 0x0209
+#define IPC_CALL_LINE_ID 0x020A
/* Enum values */
-#define MSM_CALL_TYPE_VOICE 0x01
-#define MSM_CALL_TYPE_DATA 0x03
+#define IPC_CALL_TYPE_VOICE 0x01
+#define IPC_CALL_TYPE_DATA 0x03
-#define MSM_CALL_IDENTITY_DEFAULT 0x00
-#define MSM_CALL_IDENTITY_HIDE 0x01
-#define MSM_CALL_IDENTITY_SHOW 0x02
+#define IPC_CALL_IDENTITY_DEFAULT 0x00
+#define IPC_CALL_IDENTITY_HIDE 0x01
+#define IPC_CALL_IDENTITY_SHOW 0x02
-#define MSM_CALL_PREFIX_NONE 0x00
-#define MSM_CALL_PREFIX_INTL 0x11
+#define IPC_CALL_PREFIX_NONE 0x00
+#define IPC_CALL_PREFIX_INTL 0x11
-/* Only for msm_call_status, NOT call_list */
-#define MSM_CALL_STATE_DIALING 0x01
-#define MSM_CALL_STATE_IGNORING_INCOMING_STATUS 0x02
-#define MSM_CALL_STATE_CONNECTED 0x03
-#define MSM_CALL_STATE_RELEASED 0x04
-#define MSM_CALL_STATE_CONNECTING 0x05
+/* Only for ipc_call_status, NOT call_list */
+#define IPC_CALL_STATE_DIALING 0x01
+#define IPC_CALL_STATE_IGNORING_INCOMING_STATUS 0x02
+#define IPC_CALL_STATE_CONNECTED 0x03
+#define IPC_CALL_STATE_RELEASED 0x04
+#define IPC_CALL_STATE_CONNECTING 0x05
-#define MSM_CALL_TERM_MO 0x01
-#define MSM_CALL_TERM_MT 0x02
+#define IPC_CALL_TERM_MO 0x01
+#define IPC_CALL_TERM_MT 0x02
-struct msm_call_outgoing {
+struct ipc_call_outgoing {
unsigned char type, identity;
unsigned char length, prefix;
unsigned char number[86];
} __attribute__((__packed__));
-struct msm_call_incoming {
+struct ipc_call_incoming {
unsigned char type, id, line;
} __attribute__((__packed__));
-struct msm_call_list_entry {
+struct ipc_call_list_entry {
unsigned char type, idx;
unsigned char term, state, mpty;
unsigned char number_len;
unsigned char unk4;
} __attribute__((__packed__));
-struct msm_call_status {
+struct ipc_call_status {
unsigned char type, id, state;
unsigned char reason, end_cause;
} __attribute__((__packed__));
-void msm_call_outgoing(const char *number, int identity, int request_id);
-void msm_call_release(int request_id);
-void msm_call_answer(int request_id);
-void msm_call_list(int request_id);
+void ipc_call_outgoing(const char *number, int identity, int request_id);
+void ipc_call_release(int request_id);
+void ipc_call_answer(int request_id);
+void ipc_call_list(int request_id);
#endif
@@ -1,20 +1,20 @@
/**
- * This file is part of libmsm-h1.
+ * This file is part of libsamsung-ipc.
*
* Copyright (C) 2010-2011 Joerie de Gram <j.de.gram@gmail.com>
@@ -1,20 +1,20 @@
* Copyright (C) 2010-2011 Joerie de Gram <j.de.gram@gmail.com>
*
- * libmsm-h1 is free software: you can redistribute it and/or modify
+ * libsamsung-ipc is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
@@ -1,20 +1,20 @@
* (at your option) any later version.
*
- * libmsm-h1 is distributed in the hope that it will be useful,
+ * libsamsung-ipc is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the